@@ -160,7 +160,7 @@ MOD_DEV("vmmon", LM_DT_CHAR, -1, &vmmon_cdevsw)
 int
 vmmon_lkmentry(struct lkm_table *lkmtp, int cmd, int ver)
 {
-	LKM_DISPATCH(lkmtp, NULL, cmd, vmmon_handle, vmmon_handle, vmmon_handle)
+	DISPATCH(lkmtp, cmd, ver, vmmon_handle, vmmon_handle, vmmon_handle)
 }
 
 static int 
