@@ -195,7 +195,7 @@ vmnetattach(int ndev)
 int
 vmnet_lkmentry(struct lkm_table *lkmtp, int cmd, int ver)
 {
-	LKM_DISPATCH(lkmtp, NULL, cmd, hub_handle, hub_handle, hub_handle)
+	DISPATCH(lkmtp, cmd, ver, hub_handle, hub_handle, hub_handle)
 }
 
 static int 
